SIMDJSON_UNTARGET_HASWELL
#undef SIMDJSON_IMPLEMENTATION
